Learn R Programming

smartsheetr (version 0.1.0)

ss_add_columns: Add columns to an existing sheet

Description

Add columns to an existing sheet

Usage

ss_add_columns(ss_id, data, index = 0)

Value

A ss_addcolumns_resp object

Arguments

ss_id

The sheetId, permalink, or name of the Smartsheet sheet to read

data

A data frame of columns to be added

index

The index location where the columns should be added

Examples

Run this code
if (FALSE) {
ss_id = ss_sheetid(ss_write_sheet(paste0("smartsheetr-example-",random_sheet_name())))
ss_add_columns(ss_id, data.frame("FK"=character()), index=1)
ss_read_sheet(ss_id)
# clean up
ss_delete_sheet(ss_id)
}

Run the code above in your browser using DataLab