Learn R Programming

smartsheetr (version 0.1.0)

ss_column_type: Return the Smartsheet Column Type that aligns with the R class

Description

Return the Smartsheet Column Type that aligns with the R class

Usage

ss_column_type(r_class)

Value

A character vector

Arguments

r_class

A character vector (returned from a call to base::class())

Details

See https://smartsheet.redoc.ly/tag/columnsRelated/#section/Column-Types